==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/memorydb/kotlin/inputs/GetParameterGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.memorydb.kotlin.inputs

import com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getParameterGroup.
 * @property name Name of the parameter group.
 * @property tags Map of tags assigned to the parameter group.
 */
public data class GetParameterGroupPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs> {
    override fun toJava(): com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs =
        com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetParameterGroupPlainArgs].
 */
@PulumiTagMarker
public class GetParameterGroupPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the parameter group.
     */
    @JvmName("xkgcmlaxmiwkgiuh")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags assigned to the parameter group.
     */
    @JvmName("qmjhdmuqpylxhfbp")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags assigned to the parameter group.
     */
    @JvmName("nohgibmhlccpisvw")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetParameterGroupPlainArgs = GetParameterGroupPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/memorydb/kotlin/inputs/GetParameterGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.memorydb.kotlin.inputs

import com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getParameterGroup.
 * @property name Name of the parameter group.
 * @property tags Map of tags assigned to the parameter group.
 */
public data class GetParameterGroupPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs> {
    override fun toJava(): com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs =
        com.pulumi.aws.memorydb.inputs.GetParameterGroupPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetParameterGroupPlainArgs].
 */
@PulumiTagMarker
public class GetParameterGroupPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the parameter group.
     */
    @JvmName("evudetiluwokvjnp")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags assigned to the parameter group.
     */
    @JvmName("qdvuobmjruhaiqri")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags assigned to the parameter group.
     */
    @JvmName("tlehligtrcbdfqis")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetParameterGroupPlainArgs = GetParameterGroupPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}
